@@ -7,7 +7,7 @@ RTF::Tokenizer - Tokenize RTF
 
 =head1 VERSION
 
-version 1.17
+version 1.18
 
 =head1 DESCRIPTION
 
@@ -42,6 +42,9 @@ Tokenizes RTF
  # Ooops, that was wrong...
 	$tokenizer->put_token( 'control', 'b', 1 );
 
+ # Let's have the lot...
+    my @tokens = $tokenizer->get_all_tokens();
+
 =head1 INTRODUCTION
 
 This documentation assumes some basic knowledge of RTF.
@@ -54,7 +57,7 @@ L<http://search.cpan.org/search?dist=RTF-Writer>
 require 5;
 
 package RTF::Tokenizer;
-$RTF::Tokenizer::VERSION = '1.17';
+$RTF::Tokenizer::VERSION = '1.18';
 use vars qw($VERSION);
 
 use strict;
@@ -376,6 +379,26 @@ sub get_token {
     }
 }
 
+=head2 get_all_tokens
+
+As per C<get_token>, but keeps calling C<get_token> until it hits EOF. Returns
+a list of arrayrefs.
+
+=cut
+
+sub get_all_tokens {
+    my $self = shift;
+    my @tokens;
+
+    while (1) {
+        my $token = [ $self->get_token() ];
+        push( @tokens, $token );
+        last if $token->[0] eq 'eof';
+    }
+
+    return @tokens;
+}
+
 =head2 put_token( type, token, argument )
 
 Adds an item to the token cache, so that the next time you
